@@ -12,4 +12,9 @@
 #define _KLIBC_USE_RT_SIG 1	/* Use rt_* signals */
 #define _KLIBC_SYS_SOCKETCALL 1 /* Use sys_socketcall unconditionally */
 
+/* So that we can avoid stack trampolines */
+#define _KLIBC_NEEDS_SA_RESTORER 1
+/* Our restorer will call rt_sigreturn() */
+#define _KLIBC_NEEDS_SA_SIGINFO 1
+
 #endif				/* _KLIBC_ARCHCONFIG_H */
