@@ -5,6 +5,7 @@
 #ifndef _SYS_SOCKET_H
 #define _SYS_SOCKET_H
 
+#include <sys/types.h>
 #include <klibc/extern.h>
 #include <klibc/compiler.h>
 #include <klibc/sysconfig.h>
@@ -27,8 +28,13 @@
 # define SOCK_RDM       4
 # define SOCK_SEQPACKET 5
 # define SOCK_PACKET    10
+# define SOCK_CLOEXEC   02000000
+# define SOCK_NONBLOCK  04000
 #endif
 
+/* The maximum backlock queue length. */
+#define SOMAXCONN	128
+
 #ifndef AF_INET
 #define AF_UNSPEC	0
 #define AF_UNIX		1	/* Unix domain sockets 		*/
@@ -241,10 +247,11 @@ struct ucred {
 
 
 __extern int socket(int, int, int);
-__extern int bind(int, struct sockaddr *, int);
-__extern int connect(int, struct sockaddr *, socklen_t);
+__extern int bind(int, const struct sockaddr *, int);
+__extern int connect(int, const struct sockaddr *, socklen_t);
 __extern int listen(int, int);
 __extern int accept(int, struct sockaddr *, socklen_t *);
+__extern int accept4(int, struct sockaddr *, socklen_t *, int);
 __extern int getsockname(int, struct sockaddr *, socklen_t *);
 __extern int getpeername(int, struct sockaddr *, socklen_t *);
 __extern int socketpair(int, int, int, int *);
